@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.5907';
+our $VERSION = '0.60';
 
 use warnings;
 use strict;
@@ -27,12 +27,17 @@ sub populate {
     if ($data_ref eq 'ARRAY' || $data_ref eq 'Math::Matrix') {
         my $vertex = 0; # Initial vertex id.
         for my $neighbors (@$data) {
-            $self->_from_array(
-                $vertex, $neighbors, $attr
-            );
+            $self->_from_array($vertex, $neighbors, $attr);
             $vertex++; # Move on to the next vertex...
         }
     }
+    elsif ($data_ref eq 'Math::MatrixReal') {
+        my $vertex = 0;
+        for my $neighbors (@{ $data->[0] }) {
+            $self->_from_array($vertex, $neighbors, $attr);
+            $vertex++;
+        }
+    }
     elsif ($data_ref eq 'HASH') {
         for my $vertex (keys %$data) {
             if ( $data->{$vertex}{label} ) {
@@ -212,7 +217,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.5907
+version 0.60
 
 =head1 SYNOPSIS
 
@@ -229,10 +234,10 @@ version 0.5907
  );
  for my $vertex (sort { $a <=> $b } $gw->vertices) {
     warn sprintf "vertex: %s weight=%.2f\n",
-        $vertex, $gw->get_weight($vertex);
+        $vertex, $gw->get_cost($vertex);
     for my $neighbor (sort { $a <=> $b } $gw->neighbors($vertex)) {
         warn sprintf "\tedge to: %s weight=%.2f\n",
-            $neighbor, $gw->get_weight([$vertex, $neighbor]);
+            $neighbor, $gw->get_cost([$vertex, $neighbor]);
     }
  }
 
@@ -289,8 +294,8 @@ Please see L<Graph/Constructors> for the possible constructor arguments.
 
 Populate a graph with weighted nodes.
 
-The data can be an arrayref of numeric vectors, a C<Math::MatrixReal> object, or
-a hashref of numeric edge values.
+The data can be an arrayref of numeric vectors, a C<Math::Matrix> object, a
+C<Math::MatrixReal> object, or a hashref of numeric edge values.
 
 Data given as a hash reference may also contain an optional node label, as shown
 in the SYNOPSIS.
@@ -318,31 +323,31 @@ Return the weight for the vertex or edge.
 
 =head2 get_cost()
 
-  $w = $gw->get_cost($vertex);
-  $w = $gw->get_cost($vertex, $attribute);
-  $w = $gw->get_cost(\@edge);
-  $w = $gw->get_cost(\@edge, $attribute);
+  $c = $gw->get_cost($vertex);
+  $c = $gw->get_cost($vertex, $attribute);
+  $c = $gw->get_cost(\@edge);
+  $c = $gw->get_cost(\@edge, $attribute);
 
 Return the named attribute value for the vertex or edge.
 
 =head2 vertex_span()
 
- my ($lightest, $heaviest) = $gw->vertex_span();
- my ($lightest, $heaviest) = $gw->vertex_span($attr);
+ ($lightest, $heaviest) = $gw->vertex_span();
+ ($lightest, $heaviest) = $gw->vertex_span($attr);
 
 Return the lightest and heaviest vertices.
 
 =head2 edge_span()
 
- my ($lightest, $heaviest) = $gw->edge_span();
- my ($lightest, $heaviest) = $gw->edge_span($attr);
+ ($lightest, $heaviest) = $gw->edge_span();
+ ($lightest, $heaviest) = $gw->edge_span($attr);
 
 Return the lightest to heaviest edges.
 
 =head2 path_cost()
 
- my $weight = $gw->path_cost(\@vertices);
- my $weight = $gw->path_cost(\@vertices, $attr);
+ $c = $gw->path_cost(\@vertices);
+ $c = $gw->path_cost(\@vertices, $attr);
 
 Return the summed weight (or given cost attribute) of the path edges.
 
